const ZeedhiAPIConstructor = require('zeedhi-functional-test-api');
const z = new ZeedhiAPIConstructor(browser, protractor);
const Helper = require('teknisa-helper');
const geral = new Helper.geral();
const loginPage = new Helper.login();
const tabelaDescPage = require('../../../page-objects/parametrizacao/pedidos/tabelaDesconto.po.js');
const j = require('../../../json/leitorJson.po.js');
const protractorHelper = require('protractor-helper');

const tabelaDescontoGridId = '447188831940064004254';
const descontoProporcionalGridId = '447188831167193468286';
const descontoProdutoGridId = '447188832920386349256';
const desconto = Helper.util.geraInt(1, 80);
const qntInicial = Helper.util.geraInt(100, 99800);
const qntFinal = (parseInt(qntInicial, 10) + 100);

describe('Tela Tabela de Desconto', () => {
	beforeEach(() => {
		browser.get('http://erpteste.teknisa.com/login/');
		loginPage.login(j.getValor('login'), j.getValor('senha'));
		tabelaDescPage.abrir();
	});

	afterEach(() => {
		geral.sair();
	});

	it('Deve acessar a tela Tabela de Desconto', () => {
		expect(z.component.header.getTitle()).toBe('Tabela de Desconto');
	});

	it('Deve adicionar tipo de Desconto', () => {
		tabelaDescPage.adicionarTipoDesconto(j.getValor('nomeTipoDesconto'), 'Ativo', 'Por Produto', desconto);
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${tabelaDescontoGridId}`)));

		expect(geral.gridHasText(tabelaDescontoGridId, j.getValor('nomeTipoDesconto'), 1))
			.toBe(j.getValor('nomeTipoDesconto'));
		expect(geral.gridHasText(tabelaDescontoGridId, 'Por Produto', 3))
			.toBe('Por Produto');
	});

	it('Deve editar Desconto Por Produto', () => {
		geral.clickGrid('NMTABDESC', j.getValor('nomeTipoDesconto'), tabelaDescontoGridId);
		geral.trocarAba('Desconto Por Produto');
		tabelaDescPage.editarDescontoProduto(j.getValor('produto'), j.getValor('produtoFinal'),
			j.getValor('produto'), descontoProdutoGridId, desconto);
		geral.waitFieldVisibility('VRPERDESC');

		expect(geral.getTextoPorId('VRPERDESC'))
			.toMatch(desconto);
	});

	it('Deve editar tipo de Desconto', () => {
		geral.clickGrid('NMTABDESC', j.getValor('nomeTipoDesconto'), tabelaDescontoGridId);
		tabelaDescPage.editarTipoDesconto(j.getValor('nomeTipoDesconto1'), 'Inativo',
			'Proporcional Por Quantidade', desconto);

		expect(geral.getTextoPorId('IDTIPODESC'))
			.toBe('Proporcional Por Quantidade');
		expect(geral.getTextoPorId('NMTABDESC'))
			.toBe(j.getValor('nomeTipoDesconto1'));
	});

	it('Deve adicionar Desconto Proporcional', () => {
		geral.clickGrid('NMTABDESC', j.getValor('nomeTipoDesconto1'), tabelaDescontoGridId);
		geral.trocarAba('Desconto Proporcional');
		tabelaDescPage.adicionarDescontoProporcional(
			j.getValor('produto'), qntInicial, qntFinal, desconto);

		expect(geral.gridHasText(descontoProporcionalGridId, qntInicial))
			.toBe(qntInicial);
		expect(geral.gridHasText(descontoProporcionalGridId, desconto, 2))
			.toBe(desconto);
	});

	it('Excluir Desconto Proporcional', () => {
		geral.clickGrid('NMTABDESC', j.getValor('nomeTipoDesconto1'), tabelaDescontoGridId);
		geral.trocarAba('Desconto Proporcional');
		tabelaDescPage.excluirDescontoProporcional(j.getValor('produto'), qntInicial,
			descontoProporcionalGridId);

		expect(geral.gridHasText(descontoProporcionalGridId, qntInicial))
			.toBeUndefined();
	});

	it('Excluir Tipo de Desconto', () => {
		geral.clickGrid('NMTABDESC', j.getValor('nomeTipoDesconto1'), tabelaDescontoGridId);
		geral.clickExcluir();
		geral.clickSim();
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${tabelaDescontoGridId}`)));

		expect(geral.gridHasText(tabelaDescontoGridId, j.getValor('nomeTipoDesconto'), 1))
			.toBeUndefined();
		expect(geral.gridHasText(tabelaDescontoGridId, desconto, 4))
			.toBeUndefined();
	});
});
